@@ -3,7 +3,7 @@ package Config::Onion;
 use strict;
 use warnings;
 
-our $VERSION = 1.005;
+our $VERSION = 1.006;
 
 use Config::Any;
 use Hash::Merge::Simple 'merge';
@@ -80,9 +80,18 @@ sub load_glob {
     delete $ca_opts->{flatten_to_hash} if exists $ca_opts->{flatten_to_hash};
   }
 
+  # if use_ext is on, we need to query Config::Any to see what extensions are allowed
+  my $ext_re = '';
+  if ($ca_opts->{use_ext}) {
+    my @exts = Config::Any->extensions();
+    $ext_re = '\.' . (shift @exts) . '$';
+    $ext_re .= "|\\.$_\$" foreach @exts;
+  }
+
   my (@main_files, @local_files);
   for my $globspec (@_) {
     for (glob $globspec) {
+      next if $ca_opts->{use_ext} && !/$ext_re/;
       if (/\.local\./) { push @local_files, $_ }
       else             { push @main_files,  $_ }
     }
@@ -162,7 +171,7 @@ Config::Onion - Layered configuration, because configs are like ogres
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
